==> zio-aws-cognitoidentityprovider_2.13-5.17.112.1-sources.jar: zio/aws/cognitoidentityprovider/model/RiskExceptionConfigurationType.scala <==
package zio.aws.cognitoidentityprovider.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.cognitoidentityprovider.model.primitives.StringType
import scala.jdk.CollectionConverters._
final case class RiskExceptionConfigurationType(
    blockedIPRangeList: Option[Iterable[StringType]] = None,
    skippedIPRangeList: Option[Iterable[StringType]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cognitoidentityprovider.model.RiskExceptionConfigurationType = {
    import RiskExceptionConfigurationType.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cognitoidentityprovider.model.RiskExceptionConfigurationType
      .builder()
      .optionallyWith(
        blockedIPRangeList.map(value =>
          value.map { item =>
            StringType.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.blockedIPRangeList)
      .optionallyWith(
        skippedIPRangeList.map(value =>
          value.map { item =>
            StringType.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.skippedIPRangeList)
      .build()
  }
  def asReadOnly
      : zio.aws.cognitoidentityprovider.model.RiskExceptionConfigurationType.ReadOnly =
    zio.aws.cognitoidentityprovider.model.RiskExceptionConfigurationType
      .wrap(buildAwsValue())
}
object RiskExceptionConfigurationType {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cognitoidentityprovider.model.RiskExceptionConfigurationType
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.cognitoidentityprovider.model.RiskExceptionConfigurationType =
      zio.aws.cognitoidentityprovider.model.RiskExceptionConfigurationType(
        blockedIPRangeList.map(value => value),
        skippedIPRangeList.map(value => value)
      )
    def blockedIPRangeList: Option[List[StringType]]
    def skippedIPRangeList: Option[List[StringType]]
    def getBlockedIPRangeList: ZIO[Any, AwsError, List[StringType]] =
      AwsError.unwrapOptionField("blockedIPRangeList", blockedIPRangeList)
    def getSkippedIPRangeList: ZIO[Any, AwsError, List[StringType]] =
      AwsError.unwrapOptionField("skippedIPRangeList", skippedIPRangeList)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cognitoidentityprovider.model.RiskExceptionConfigurationType
  ) extends zio.aws.cognitoidentityprovider.model.RiskExceptionConfigurationType.ReadOnly {
    override val blockedIPRangeList: Option[List[StringType]] = scala
      .Option(impl.blockedIPRangeList())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.cognitoidentityprovider.model.primitives.StringType(item)
        }.toList
      )
    override val skippedIPRangeList: Option[List[StringType]] = scala
      .Option(impl.skippedIPRangeList())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.cognitoidentityprovider.model.primitives.StringType(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cognitoidentityprovider.model.RiskExceptionConfigurationType
  ): zio.aws.cognitoidentityprovider.model.RiskExceptionConfigurationType.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-cognitoidentityprovider_2.13-5.17.130.5-sources.jar: zio/aws/cognitoidentityprovider/model/RiskExceptionConfigurationType.scala <==
package zio.aws.cognitoidentityprovider.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.cognitoidentityprovider.model.primitives.StringType
import scala.jdk.CollectionConverters._
final case class RiskExceptionConfigurationType(
    blockedIPRangeList: Option[Iterable[StringType]] = None,
    skippedIPRangeList: Option[Iterable[StringType]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cognitoidentityprovider.model.RiskExceptionConfigurationType = {
    import RiskExceptionConfigurationType.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cognitoidentityprovider.model.RiskExceptionConfigurationType
      .builder()
      .optionallyWith(
        blockedIPRangeList.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.blockedIPRangeList)
      .optionallyWith(
        skippedIPRangeList.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.skippedIPRangeList)
      .build()
  }
  def asReadOnly
      : zio.aws.cognitoidentityprovider.model.RiskExceptionConfigurationType.ReadOnly =
    zio.aws.cognitoidentityprovider.model.RiskExceptionConfigurationType
      .wrap(buildAwsValue())
}
object RiskExceptionConfigurationType {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cognitoidentityprovider.model.RiskExceptionConfigurationType
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.cognitoidentityprovider.model.RiskExceptionConfigurationType =
      zio.aws.cognitoidentityprovider.model.RiskExceptionConfigurationType(
        blockedIPRangeList.map(value => value),
        skippedIPRangeList.map(value => value)
      )
    def blockedIPRangeList: Option[List[StringType]]
    def skippedIPRangeList: Option[List[StringType]]
    def getBlockedIPRangeList: ZIO[Any, AwsError, List[StringType]] =
      AwsError.unwrapOptionField("blockedIPRangeList", blockedIPRangeList)
    def getSkippedIPRangeList: ZIO[Any, AwsError, List[StringType]] =
      AwsError.unwrapOptionField("skippedIPRangeList", skippedIPRangeList)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cognitoidentityprovider.model.RiskExceptionConfigurationType
  ) extends zio.aws.cognitoidentityprovider.model.RiskExceptionConfigurationType.ReadOnly {
    override val blockedIPRangeList: Option[List[StringType]] = scala
      .Option(impl.blockedIPRangeList())
      .map(value =>
        value.asScala.map { item =>
          item: StringType
        }.toList
      )
    override val skippedIPRangeList: Option[List[StringType]] = scala
      .Option(impl.skippedIPRangeList())
      .map(value =>
        value.asScala.map { item =>
          item: StringType
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cognitoidentityprovider.model.RiskExceptionConfigurationType
  ): zio.aws.cognitoidentityprovider.model.RiskExceptionConfigurationType.ReadOnly =
    new Wrapper(impl)
}
